package App::1234567891 ;  
our $VERSION = '0.010' ; 
our $DATE = '2025-03-18T12:30+09:00' ; 

=encoding utf8

=head1 NAME

App::1234567891 - Yield the number sequence 123456789112345678921234567893... for measuring the character string length on your editor. 

=head1 SYNOPSIS

This module provides a Unix-like command `F<1234567891>'. 

=head1 DESCRIPTION

=head1 SEE ALSO

1234567891 --help
man 1234567891
perldoc 1234567891

=cut

1 ;
